==> leonardo-0.6b1.tgz: leonardo-0.6b1/bin/regen_index.py <==
#!/usr/bin/env python
#
#    Copyright (C) 2003-2005  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

"""
This script regenerates the property index.
"""

import sys
import os
import os.path

# adjust accordingly if need be
sys.path.append("../lib/")

import filesystem

def usage():
    print 'Usage:', sys.argv[0], '<lfs_root>'
    sys.exit(0)


if len(sys.argv) != 2:
    usage()

lfs_root = sys.argv[1]

lfs = filesystem.LeonardoFileSystem(lfs_root)

index_filename = os.path.join(lfs_root, "property_index")
if os.access(index_filename, os.F_OK):
    os.remove(index_filename)
    

def reindex(lfs, key=""):
    directories, files = lfs.get_children(key)
    for filename in files:
        f = lfs.get(key + "/" + filename)
        print f.key
        for name in f.get_properties():
            value = f.get_property(name)
            if value != None:
                print "\t", name, value
                lfs.add_property(f.key, name, value)
        
    for directory in directories:
        reindex(lfs, key + "/" + directory)



reindex(lfs)

==> leonardo-0.7b1.tgz: leonardo-0.7b1/bin/regen_index.py <==
#!/usr/bin/env python
#
#    Copyright (C) 2003-2005  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

"""
This script regenerates the property index.
"""

import sys
import os
import os.path

# adjust accordingly if need be
sys.path.append("../lib/")

from leonardo import filesystem

def usage():
    print 'Usage:', sys.argv[0], '<lfs_root>'
    sys.exit(0)


if len(sys.argv) != 2:
    usage()

lfs_root = sys.argv[1]

lfs = filesystem.LeonardoFileSystem(lfs_root)

index_filename = os.path.join(lfs_root, "property_pickle")
if os.access(index_filename, os.F_OK):
    os.remove(index_filename)
    

def reindex(lfs, key=""):
    directories, files = lfs.get_children(key)
    for filename in files:
        # we use os.path.join because if key="" we don't want initial slash
        f = lfs.get(os.path.join(key, filename))
        print f.key
        for name in f.get_properties():
            value = f.get_property(name)
            if value != None:
                print "\t", name, value
                lfs.add_property(f.key, name, value)
        
    for directory in directories:
        reindex(lfs, os.path.join(key, directory))



reindex(lfs)
